@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     nanoterm
     ~~~~~~~~
@@ -11,8 +10,6 @@
     :license: LGPL, see LICENSE for more details.
 """
 
-from __future__ import print_function, unicode_literals
-
 import os
 import pty
 import select
